/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/

#include <AppKit/AppKit.h>

@class MIMainViewController;

@interface MIApplication : NSApplication
{
	NSMethodSignature*	fSignature;
	NSMutableArray*		fKeyCommands;
	MIMainViewController *fMainViewController;
}

- (id)init;
- (void)dealloc;

// the selector for the registerKeyCommand:modifiers:forTarget:selector: method should have
// the same signature as the following method :
// - (void)performKeyCommand:(NSString*)key withModifiers:(unsigned int)modifiers;
- (void)registerKeyCommand:(NSString*)key modifiers:(unsigned int)modifiers forTarget:(id)target selector:(SEL)selector;

- (void)unregisterKeyCommandsForTarget:(id)target;
- (void)unregisterKeyCommand:(NSString*)key modifiers:(unsigned int)modifiers forTarget:(id)target;

- (NSMenuItem*)searchForMenuItemWithTag:(int)tag;

- (MIMainViewController*)mainViewController;
- (void)resetMainViewController;

@end

@interface MIKeyCommand : NSObject {
	NSString *fKeyCommand;
	unsigned int fModifiers;
	id fTarget;
	SEL fSelector;
}

- (id)initWithKey:(NSString*)key modifiers:(unsigned int)modifiers forTarget:(id)target selector:(SEL)selector;
- (void)dealloc ;

- (NSString*)key;
- (unsigned int)modifiers;
- (id)target;
- (SEL)selector;

@end

@interface NSEvent (MTGCarbonModifiers)

+ (unsigned int)modifiers;

@end

@interface NSScreen (MIScreenAdditions)

+ (NSScreen*)menubarScreen;

@end

@interface NSView (MIViewAdditions)

- (NSView*)viewOfClass:(Class)classToFind;

@end

@interface NSWindow (MIWindowAdditions)

- (void)centerOnMenubarScreen;

@end


@interface NSString (BaseConversionAddition)

- (int)intValueFromStringExpressedInBase:(short)base;
+ (NSString*)stringExpressedInBase:(short)base FromInt:(int)integer;

@end

@interface NSString (PathAddition)

- (NSString*)mountPoint;

@end

@interface NSColorPanel (MIAdditions)

- (void)setFloatAboveModalWindows:(BOOL)flag;

@end



/*@interface MIDelayedInvocation : NSObject {
	SEL fSelector;
	id fTarget;
	id fObject;
}

+ (void)invoqueSelectorWithDelay:(SEL)selector target:(id)target object:(id)object;

@end*/

void MIRunErrorPanel( NSString *title, NSString *nonTechnicalReason, NSString *errorNumber, NSString *technicalReason );
